import argparse
import os




def main():
	args = argparse.ArgumentParser(description="Generates a Punnet Square using given arguments")

	args.add_argument("-f", "--female", nargs=2, help="Females Genes", action="store", required=True)
	args.add_argument("-m", "--male", nargs=2, help="Males Genes", action="store", required=True)


	ootput = args.parse_args()
	f_g = ootput.female
	m_g = ootput.male


	punnet = """
	       |
	{0: <6} | {m[0]: ^5} | {m[1]: ^5} |
	{1: <3} | {f[0]: ^5} | {f[1]: ^5} |
	--------------------------------------------
	{2: <6} | {m[0]: >2}{f[0]: <4}| {m[1]: >2}{f[0]: <4}|
	{2: <6} | {m[0]: >2}{f[1]: <4}| {m[1]: >2}{f[1]: <4}|


	""".format("Male >", "Female", "    ", f=f_g, m=m_g)
	print(punnet)




#!/usr/bin/env python3

from distutils.core import setup
from setuptools import find_packages

setup(name="pungen",
      version="1.0",
      author="Ennis Massey",
      author_email="ennisbaradine@gmail.com",
      description="A simple program to generate Punnet Squares from CLI",
      scripts=["bin/pungen"],
      packages=find_packages(),
      url="https://github.com/MicroTransactionsMatterToo/punnet-generator",
      classifiers=[
          "Programming Language :: Python :: 3 :: Only",
          "Topic :: Scientific/Engineering",
          "Topic :: Utilities",
          "Environment :: Console",
          "Development Status :: 5 - Production/Stable",
          "License :: OSI Approved :: Apache Software License"
      ])